carrot.backends.pikachu — Carrot v0.10.5 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Carrot v0.10.5 documentation »
- API Reference »

# carrot.backends.pikachu

#### Previous topic

carrot.backends.pyamqplib

#### Next topic

carrot.backends.pystomp

### This Page

- Show Source

### Quick search

Enter search terms or a module, class or function name.

### Navigation

- index
- modules |
- next |
- previous |
- Carrot v0.10.5 documentation »
- API Reference »

© Copyright 2009, Ask Solem. Created using Sphinx 1.0b2.